@@ -53,7 +53,7 @@ public:
 
   virtual int numberOfCategories(Axis axis = Axis::X) const override;
   virtual WString categoryLabel(int u, Axis axis = Axis::X) const override;
-  virtual RenderRange computeRenderRange(Axis axis, int xAxis, int yAxis, AxisScale scale) const override;
+  virtual RenderRange computeRenderRange(Axis axis, int xAxis, int yAxis, AxisScale scale = AxisScale::Linear) const override;
 
   virtual bool onDemandLoadingEnabled() const override;
 
